@@ -1,6 +1,12 @@
 """ Cli tool for testing connectivity with EQ3 smart thermostats. """
+import sys
+if sys.version_info < (3,4):
+    print("To use this script you need python 3.4 or newer! got %s" % sys.version_info)
+    sys.exit(1)
+
 import logging
 import click
+import re
 from click_datetime import Datetime
 
 from eq3bt import Thermostat
@@ -8,8 +14,13 @@ from eq3bt import Thermostat
 pass_dev = click.make_pass_decorator(Thermostat)
 
 
+def validate_mac(ctx, param, mac):
+    if re.match('^([0-9A-Fa-f]{2}:){5}[0-9A-Fa-f]{2}$', mac) is None:
+        raise click.BadParameter(mac + ' is no valid mac address')
+    return mac
+
 @click.group(invoke_without_command=True)
-@click.option('--mac', envvar="EQ3_MAC")
+@click.option('--mac', envvar="EQ3_MAC", required=True, callback=validate_mac)
 @click.option('--debug/--normal', default=False)
 @click.pass_context
 def cli(ctx, mac, debug):
